<?xml version="1.0" encoding="UTF-8"?>
<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/">
  <channel rdf:about="http://blog.gmane.org/gmane.comp.lang.haskell.cvs.ghc">
    <title>gmane.comp.lang.haskell.cvs.ghc</title>
    <link>http://blog.gmane.org/gmane.comp.lang.haskell.cvs.ghc</link>
    <description/>
    <syn:updatePeriod>hourly</syn:updatePeriod>
    <syn:updateFrequency>1</syn:updateFrequency>
    <syn:updateBase>1901-01-01T00:00+00:00</syn:updateBase>
    <items>
      <rdf:Seq>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58366"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58365"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58364"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58363"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58362"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58361"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58360"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58359"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58358"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58357"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58356"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58355"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58354"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58353"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58352"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58351"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58350"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58349"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58348"/>
        <rdf:li rdf:resource="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58347"/>
      </rdf:Seq>
    </items>
    <image rdf:resource="http://gmane.org/img/gmane-25t.png"/>
    <textinput rdf:resource=""/>
  </channel>
  <image rdf:about="http://gmane.org/img/gmane-25t.png">
    <title>Gmane</title>
    <url>http://gmane.org/img/gmane-25t.png</url>
    <link>http://gmane.org</link>
  </image>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58366">
    <title>[commit: testsuite] master: Wibbles in debug output (d3c5450)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58366</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/testsuite

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/d3c545096d3cd32af817beaf4b0f26fe022a7760


commit d3c545096d3cd32af817beaf4b0f26fe022a7760
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:29:52 2012 +0100

    Wibbles in debug output


 tests/th/TH_RichKinds2.stderr |   15 +++++++--------
 1 files changed, 7 insertions(+), 8 deletions(-)

diff --git a/tests/th/TH_RichKinds2.stderr b/tests/th/TH_RichKinds2.stderr
index a3f836a..625d03e 100644
--- a/tests/th/TH_RichKinds2.stderr
+++ b/tests/th/TH_RichKinds2.stderr
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1,10 +1,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 
 TH_RichKinds2.hs:23:4: Warning:
-    data SMaybe_0 (t_1 :: k_0 -&amp;gt;
-                      *) (t_2 :: Data.Maybe.Maybe k_0)
-    = forall . t_2 ~ 'Data.Maybe.Nothing =&amp;gt; SNothing_3
-    | forall a_4 . t_2 ~ 'Data.Maybe.Just a_4 =&amp;gt; SJust_5 (t_1 a_4)
-type instance TH_RichKinds2.Map f_6 '[] = '[]
-type instance TH_RichKinds2.Map f_7
-                                ('GHC.Types.: h_8 t_9) = 'GHC.Types.: (f_7 h_8)
-                                                                      (TH_RichKinds2.Map f_7 t_9)
+    data SMaybe_0 (t_1 :: k_0 -&amp;gt; *) (t_3 :: Data.Maybe.Maybe k_0)
+    = forall . t_3 ~ 'Data.Maybe.Nothing =&amp;gt; SNothing_4
+    | forall a_5 . t_3 ~ 'Data.Maybe.Just a_5 =&amp;gt; SJust_6 (t_1 a_5)
+type instance TH_RichKinds2.Map f_7 '[] = '[]
+type instance TH_RichKinds2.Map f_8
+                                ('GHC.Types.: h_9 t_10) = 'GHC.Types.: (f_8 h_9)
+                                                                       (TH_RichKinds2.Map f_8 t_10)
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:56</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58365">
    <title>[commit: testsuite] master: Test Trac #6120 (fd30482)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58365</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/testsuite

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/fd30482f38c5cb5527f03afee233839611652997


commit fd30482f38c5cb5527f03afee233839611652997
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 14:04:35 2012 +0100

    Test Trac #6120


 tests/rename/should_compile/T6120.hs |   10 ++++++++++
 tests/rename/should_compile/all.T    |    1 +
 2 files changed, 11 insertions(+), 0 deletions(-)

diff --git a/tests/rename/should_compile/T6120.hs b/tests/rename/should_compile/T6120.hs
new file mode 100644
index 0000000..e35d221
--- /dev/null
+++ b/tests/rename/should_compile/T6120.hs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -0,0 +1,10 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
+module T6120 where
+
+infix 3 +++ 
+
+class C a where
+  (+++) :: a -&amp;gt; a -&amp;gt; a
+
+{-# DEPRECATED fail "fail is deprecated" #-}
+fail :: String -&amp;gt; String
+fail = id
diff --git a/tests/rename/should_compile/all.T b/tests/rename/should_compile/all.T
index 0fb103f..95174b1 100644
--- a/tests/rename/should_compile/all.T
+++ b/tests/rename/should_compile/all.T
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -190,3 +190,4 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; test('T5867',
      extra_clean(['T5867a.hi', 'T5867a.o']),
      multimod_compile, ['T5867', '-v0'])
 test('T6027', normal, compile, [''])
+test('T6120', normal, compile, [''])
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:59</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58364">
    <title>[commit: testsuite] master: Extend test for Trac #2713 (cf Trac#6120) (5ea2c02)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58364</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/testsuite

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/5ea2c02354a7b91371fd75ca1c1f0ab96dea80ab


commit 5ea2c02354a7b91371fd75ca1c1f0ab96dea80ab
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:29:35 2012 +0100

    Extend test for Trac #2713 (cf Trac #6120)


 tests/th/T2713.hs     |    3 +++
 tests/th/T2713.stderr |    6 +++++-
 2 files changed, 8 insertions(+), 1 deletions(-)

diff --git a/tests/th/T2713.hs b/tests/th/T2713.hs
index 77eb704..980d499 100644
--- a/tests/th/T2713.hs
+++ b/tests/th/T2713.hs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -4,6 +4,9 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; module Fixity where
 class MyClass a where
     (.*.) :: a -&amp;gt; a -&amp;gt; a
 
+f x = x
+
 $( [d| x = undefined |] )
 
 infixr 3 .*.
+f :: Int -&amp;gt; Int
diff --git a/tests/th/T2713.stderr b/tests/th/T2713.stderr
index a252888..16f130c 100644
--- a/tests/th/T2713.stderr
+++ b/tests/th/T2713.stderr
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1,4 +1,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
 
-T2713.hs:9:10:
+T2713.hs:11:10:
     The fixity signature for `.*.' lacks an accompanying binding
       (The fixity signature must be given where `.*.' is declared)
+
+T2713.hs:12:1:
+    The type signature for `f' lacks an accompanying binding
+      (The type signature must be given where `f' is declared)
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:53</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58363">
    <title>[commit: testsuite] master: Merge branch 'master' ofhttp://darcs.haskell.org/testsuite (81f799c)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58363</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/testsuite

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/81f799ce8ca118700daa9c323da74227880115bb


commit 81f799ce8ca118700daa9c323da74227880115bb
Merge: b7ada1c... a95c63d...
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:22:23 2012 +0100

    Merge branch 'master' of http://darcs.haskell.org/testsuite

 driver/runtests.py                       |   11 +++++++++++
 tests/codeGen/should_run/cgrun057.stderr |    3 ++-
 tests/ghci/scripts/T6105.hs              |    2 ++
 tests/ghci/scripts/T6105.script          |    3 +++
 tests/ghci/scripts/T6105.stdout          |    4 ++++
 tests/ghci/scripts/all.T                 |    1 +
 6 files changed, 23 insertions(+), 1 deletions(-)
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:51</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58362">
    <title>[commit: testsuite] master: Test Trac #6118 (b7ada1c)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58362</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/testsuite

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/b7ada1c5b5470c0738e82eb842538c0264d9ce6e


commit b7ada1c5b5470c0738e82eb842538c0264d9ce6e
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Tue May 22 15:18:30 2012 +0100

    Test Trac #6118


 tests/polykinds/T6118.hs |   23 +++++++++++++++++++++++
 tests/polykinds/all.T    |    1 +
 2 files changed, 24 insertions(+), 0 deletions(-)

diff --git a/tests/polykinds/T6118.hs b/tests/polykinds/T6118.hs
new file mode 100644
index 0000000..df510ff
--- /dev/null
+++ b/tests/polykinds/T6118.hs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -0,0 +1,23 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt;
+{-# LANGUAGE PolyKinds, DataKinds, KindSignatures, RankNTypes,
+             TypeFamilies, FlexibleInstances, UndecidableInstances #-}
+
+module T6118 where
+
+import GHC.Exts
+
+data Nat = Zero | Succ Nat
+data List a = Nil | Cons a (List a)
+
+class SingE (a :: k) where
+  type Demote a :: *
+
+instance SingE (a :: Bool) where
+  type Demote a = Bool
+instance SingE (a :: Nat) where
+  type Demote a = Nat
+
+instance SingE (a :: Maybe k) where
+  type Demote a = Maybe (Demote (Any :: k))
+
+instance SingE (a :: List k) where
+  type Demote (a :: List k) = List (Demote (Any :: k))
\ No newline at end of file
diff --git a/tests/polykinds/all.T b/tests/polykinds/all.T
index a9b44af..2261fda 100644
--- a/tests/polykinds/all.T
+++ b/tests/polykinds/all.T
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -49,3 +49,4 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; test('T6015', normal, compile, [''])
 test('T6015a', normal, compile, [''])
 test('T6068', normal, ghci_script, ['T6068.script'])
 test('RedBlack', normal, compile, [''])
+test('T6118', normal, compile,[''])
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:46</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58361">
    <title>[commit: ghc] master: Tidy up the treatment of signatures (inclfixity) (bc188bb)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58361</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/bc188bbdc506ac898092c87d2db3ff5f96ab4b92


commit bc188bbdc506ac898092c87d2db3ff5f96ab4b92
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:28:58 2012 +0100

    Tidy up the treatment of signatures (incl fixity)
    
    This fixes Trac #6120.  I've added comments to explain.
    Turns out there was another lurking bug, also fixed,
    and tested in (an extended version of) th/T2713.

 compiler/rename/RnBinds.lhs  |   14 +++---
 compiler/rename/RnEnv.lhs    |   87 +++++++++++++++++++++++++++++------------
 compiler/rename/RnSource.lhs |   22 +++++++----
 3 files changed, 82 insertions(+), 41 deletions(-)


Diff suppressed because of size. To see it, use:

    git show bc188bbdc506ac898092c87d2db3ff5f96ab4b92
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:11</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58360">
    <title>[commit: ghc] master: Fix an assertion failure in the stage2 compiler(0d9c2e8)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58360</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/0d9c2e8c6c8781dc5afdb9f2b778c506b09fdfbe


commit 0d9c2e8c6c8781dc5afdb9f2b778c506b09fdfbe
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:27:12 2012 +0100

    Fix an assertion failure in the stage2 compiler
    
    Rather an unsavory fix, but will go away when we do the major
    TH reorganisation from my blog post.


 compiler/typecheck/TcHsType.lhs |   11 ++++++++++-
 1 files changed, 10 insertions(+), 1 deletions(-)

diff --git a/compiler/typecheck/TcHsType.lhs b/compiler/typecheck/TcHsType.lhs
index b780c3b..a380882 100644
--- a/compiler/typecheck/TcHsType.lhs
+++ b/compiler/typecheck/TcHsType.lhs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -829,15 +829,24 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; kindGeneralize tkvs
   = do { gbl_tvs  &amp;lt;- tcGetGlobalTyVars -- Already zonked
        ; tidy_env &amp;lt;- tcInitTidyEnv
        ; tkvs     &amp;lt;- zonkTyVarsAndFV tkvs
-       ; let kvs_to_quantify = varSetElems (tkvs `minusVarSet` gbl_tvs)
+       ; let kvs_to_quantify = filter isKindVar (varSetElems (tkvs `minusVarSet` gbl_tvs))
                 -- Any type varaibles in tkvs will be in scope,
                 -- and hence in gbl_tvs, so after removing gbl_tvs
                 -- we should only have kind variables left
+--
+ -- BUT there is a smelly case (to be fixed when TH is reorganised)
+--     f t = [| e :: $t |]
+                -- When typechecking the body of the bracket, we typecheck $t to a
+                -- unification variable 'alpha', with no biding forall.  We don't
+                -- want to kind-quantify it!
 
              (_, tidy_kvs_to_quantify) = tidyTyVarBndrs tidy_env kvs_to_quantify
                            -- We do not get a later chance to tidy!
 
        ; ASSERT2 (all isKindVar kvs_to_quantify, ppr kvs_to_quantify $$ ppr tkvs)
+             -- This assertion is obviosy true because of the filter isKindVar
+             -- but we'll remove that when reorganising TH, and then the assertion
+             -- will mean something
          zonkQuantifiedTyVars tidy_kvs_to_quantify }
 \end{code}
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:08</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58359">
    <title>[commit: ghc] master: Wibbles from 'Fix scoping of kind variables ininstance declarations' (aa48740)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58359</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/aa487406a0ff96a2e02ebe6c40b5191dabcc9b2e


commit aa487406a0ff96a2e02ebe6c40b5191dabcc9b2e
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:26:31 2012 +0100

    Wibbles from 'Fix scoping of kind variables in instance declarations'
    
    This earlier commit
      6a8b4290 * Fix scoping of kind variables in instance declarations
    make became a bit more rigourous about ensuring that the kind-variable
    field of LHsTyVarBndrs was properly filled after renaming.  This patch
    fixed DsMeta to follow suit.


 compiler/deSugar/DsMeta.hs |   27 +++++++++++++++------------
 1 files changed, 15 insertions(+), 12 deletions(-)

diff --git a/compiler/typecheck/TcMType.lhs b/compiler/typecheck/TcMType.lhs
index 79b6b02..fed96e2 100644
--- a/compiler/typecheck/TcMType.lhs
+++ b/compiler/typecheck/TcMType.lhs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -1659,7 +1659,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; checkValidFamInst typats rhs
    mapM_ addErrTc (checkFamInstRhs typats (tcTyFamInsts rhs))
        }
 
--- Make sure that each type family instance is 
+-- Make sure that each type family application is 
 --   (1) strictly smaller than the lhs,
 --   (2) mentions no type variable more often than the lhs, and
 --   (3) does not contain any further type family instances.
diff --git a/compiler/typecheck/TcType.lhs b/compiler/typecheck/TcType.lhs
index b45824f..da55e72 100644
--- a/compiler/typecheck/TcType.lhs
+++ b/compiler/typecheck/TcType.lhs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -609,8 +609,8 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; tidyCos env = map (tidyCo env)
 %************************************************************************
 
 \begin{code}
-
--- | Finds type family instances occuring in a type after expanding synonyms.
+-- | Finds outermost type-family applications occuring in a type,
+-- after expanding synonyms.
 tcTyFamInsts :: Type -&amp;gt; [(TyCon, [Type])]
 tcTyFamInsts ty 
   | Just exp_ty &amp;lt;- tcView ty    = tcTyFamInsts exp_ty
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:04:56</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58354">
    <title>[nightly] 23-May-2012 build of HEAD on i386-unknown-linux (cam-02-unx)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58354</link>
    <description>&lt;pre&gt;Build description = HEAD on i386-unknown-linux (cam-02-unx)
Build location    = /playpen/simonmar/nightly/HEAD
Build config file = /home/simonmar/nightly/site/msrc/conf-HEAD-cam-02-unx

Nightly build started on cam-02-unx at Wed May 23 18:00:01 BST 2012.
**** checking out new source tree                 ... ok.
**** Building stage 1 compiler                    ... ok.
GHC Version 7.5.20120523
**** Building stage 2 compiler                    ... ok.
**** Building stage 3 compiler                    ... ok.
**** building testsuite tools                     ... ok.
**** running tests                                ... ok (summary below).
**** building compiler binary distribution        ... ok.
**** uploading binary distribution                ... ok.
**** running nofib (-rtsopts -O2)                 ... ok.
**** running nofib (-rtsopts -O2 -fllvm)          ... ok. (5 failures)
**** running nofib (-rtsopts -O2 -prof -auto-all) ... ok. (2 failures)
**** running nofib (-rtsopts -O2 -prof -auto-all -fllvm)... ok. (1 failures)
**** publishing logs                              ... ssh: connect to host haskell.org port 22: No route to host
lost connection
failed.
Logs  are at http://www.haskell.org/ghc/dist/current/logs
Dists are at http://www.haskell.org/ghc/dist/current/dist
Docs  are at http://www.haskell.org/ghc/dist/current/docs
-----------------------------------------------------------------------------
Respository hashes:
.|634fb8d3b569276504be317783ade54508633b10
ghc-tarballs|5e1f5d19ef2f836d180947aadc0dd9a9851edf28
libraries/Cabal|cc2c5a78f8fd5b2ab2c0dd3629a8184e7e0c95c4
libraries/Win32|bda29f7fe0b61b70f558549407e598c9256ad293
libraries/array|2a3d41bcae1d0a5d192e614370459dfdd31f3bcf
libraries/base|dc521b8b23847b07072a1aea0f56614ae2370e02
libraries/binary|527be910f16a4bc047069281fc58bc6748e5fecc
libraries/bytestring|fc8e1ee849b10fe2b63eb1024aff3d6624ddd069
libraries/containers|d4e8b5bd70f87af4463410df3aade72d42d675e0
libraries/deepseq|61d95ab64b1610817288e6f6b880ca2770fcc68f
libraries/directory|854bd9e4ec8c502327300c939ad197cbc39bde2c
libraries/dph|01416ec30eb73ac512cdf894a7bb44e5cebd8457
libraries/filepath|f451c8b4330fb69573533ed19a2645afa936ccaf
libraries/ghc-prim|529167773a9a036d7d3262707be4c5a2f6a04bcf
libraries/haskeline|bd39c0ce02ad07515450bfe5d667ce1635221b04
libraries/haskell2010|07f24cea759fae7994c89d77fae199862d9e2acf
libraries/haskell98|857ba8b14bba4b597d104e3d7264aee4bb4e74ae
libraries/hoopl|1ef68d6f2a8a7e89a5ed4cc78e3fefc89dc8ccab
libraries/hpc|4d661848575009bbcf3fe8e1f7c69da12f1d3a8e
libraries/integer-gmp|121cd52f9ae00ff0d6d072cc51939fb887db3fba
libraries/integer-simple|87ce6a97d7a07badc73d599a7b2ee629b2967866
libraries/old-locale|201f149646b5c2be6145436449d66bc69563c635
libraries/old-time|b2c2c9d01c3c71a9a37c11b455aba63b7a3199c2
libraries/parallel|e8ee35f4bb43cfde410d27e056d4083ced0a24c9
libraries/pretty|ab7e8d91470bb94c9e184dffbec89d0aae116f9b
libraries/primitive|75c3379b6d76e914cc3c7ffd290b6b1cad7ea3e6
libraries/process|76fb4b7e8861dec8054723a3c794c73511d07bb2
libraries/random|69bfde219bab869729fdbe9c1496371f912bf41e
libraries/stm|f3a4ab56195f943e149ccc14fbfe18c00d2fea70
libraries/template-haskell|e6323fef1a67cf9d8e91ca35d71a9c89d2494413
libraries/terminfo|64d1e6201b490942636f5f3883cf5e81c2338fc8
libraries/transformers|a59fb93860f84ccd44178dcbbb82cfea7e02cd07
libraries/unix|389820b2bcdc32be728e05fd98b69382f9c55721
libraries/utf8-string|d7386bea7fe286483ea559fb9b3898be080af700
libraries/vector|c4c5a740ec977a4300449bc85f4707ec641be923
libraries/xhtml|e6dc0c800f5a1c3ac8f0fcb477b2d76394c30d38
nofib|40c01620651d93166e2b8da156f113a4e7b827de
testsuite|a95c63d1c7196c222c4f1193181cb801cc273e42
utils/haddock|fef07ac22cc89888e78233807e55c7dbf6f405f5
utils/hsc2hs|b46ae9e455a4e6766a4dba688c9bc2186056218a
-----------------------------------------------------------------------------
All done!
Nightly build finished successfully at Thu May 24 08:44:33 BST 2012

------------- GHC Test summary ---------------------

OVERALL SUMMARY for test run started at Thu May 24 00:44:03 BST 2012
    3340 total tests, which gave rise to
   16429 test cases, of which
       0 caused framework failures
    3553 were skipped

   12541 expected passes
     194 had missing libraries
     126 expected failures
       4 unexpected passes
      11 unexpected failures

Unexpected passes:
   typecheck/should_compile  tc078 (hpc,optasm,profasm)
   typecheck/should_compile  tc126 (optasm)

Unexpected failures:
   ../../libraries/template-haskell/tests  dataToExpQUnit [exit code non-0] (profasm)
   dph/nbody                               dph-nbody-copy-opt [exit code non-0] (normal,threaded1,threaded2)
   dph/words                               dph-words-copy-opt [exit code non-0] (normal)
   ffi/should_run                          capi_value [bad stdout or stderr] (ghci)
   ffi/should_run                          ffi_parsing_001 [bad stdout or stderr] (ghci)
   perf/compiler                           T1969 [stat not good enough] (normal)
   perf/compiler                           T3064 [stat not good enough] (normal)
   perf/compiler                           T4801 [stat not good enough] (normal)
   rts                                     5250 [bad exit code] (optllvm)

----------------------------------------------------
Nightly run ended at Thu May 24 08:44:33 BST 2012
&lt;/pre&gt;</description>
    <dc:creator>GHC Build Reports</dc:creator>
    <dc:date>2012-05-24T07:44:34</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58353">
    <title>[nightly] 23-May-2012 build of HEAD (unreg) on x86_64-unknown-linux(cam-04-unx)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58353</link>
    <description>&lt;pre&gt;Build description = HEAD (unreg) on x86_64-unknown-linux (cam-04-unx)
Build location    = /64playpen/simonmar/nightly/HEAD-unreg-cam-04-unx
Build config file = /home/simonmar/nightly/site/msrc/conf-HEAD-unreg-cam-04-unx

Nightly build started on cam-04-unx at Wed May 23 18:20:02 BST 2012.
**** checking out new source tree                 ... ok.
**** Building stage 1 compiler                    ... ok.
GHC Version 7.5
**** Building stage 2 compiler                    ... ok.
**** Building stage 3 compiler                    ... ok.
**** building testsuite tools                     ... ok.
**** running tests                                ... ok (summary below).
**** running nofib (-rtsopts -O2)                 ... ok.
-----------------------------------------------------------------------------
Respository hashes:
.|634fb8d3b569276504be317783ade54508633b10
ghc-tarballs|5e1f5d19ef2f836d180947aadc0dd9a9851edf28
libraries/Cabal|cc2c5a78f8fd5b2ab2c0dd3629a8184e7e0c95c4
libraries/Win32|bda29f7fe0b61b70f558549407e598c9256ad293
libraries/array|2a3d41bcae1d0a5d192e614370459dfdd31f3bcf
libraries/base|dc521b8b23847b07072a1aea0f56614ae2370e02
libraries/binary|527be910f16a4bc047069281fc58bc6748e5fecc
libraries/bytestring|fc8e1ee849b10fe2b63eb1024aff3d6624ddd069
libraries/containers|d4e8b5bd70f87af4463410df3aade72d42d675e0
libraries/deepseq|61d95ab64b1610817288e6f6b880ca2770fcc68f
libraries/directory|854bd9e4ec8c502327300c939ad197cbc39bde2c
libraries/dph|01416ec30eb73ac512cdf894a7bb44e5cebd8457
libraries/filepath|f451c8b4330fb69573533ed19a2645afa936ccaf
libraries/ghc-prim|529167773a9a036d7d3262707be4c5a2f6a04bcf
libraries/haskeline|bd39c0ce02ad07515450bfe5d667ce1635221b04
libraries/haskell2010|07f24cea759fae7994c89d77fae199862d9e2acf
libraries/haskell98|857ba8b14bba4b597d104e3d7264aee4bb4e74ae
libraries/hoopl|1ef68d6f2a8a7e89a5ed4cc78e3fefc89dc8ccab
libraries/hpc|4d661848575009bbcf3fe8e1f7c69da12f1d3a8e
libraries/integer-gmp|121cd52f9ae00ff0d6d072cc51939fb887db3fba
libraries/integer-simple|87ce6a97d7a07badc73d599a7b2ee629b2967866
libraries/old-locale|201f149646b5c2be6145436449d66bc69563c635
libraries/old-time|b2c2c9d01c3c71a9a37c11b455aba63b7a3199c2
libraries/parallel|e8ee35f4bb43cfde410d27e056d4083ced0a24c9
libraries/pretty|ab7e8d91470bb94c9e184dffbec89d0aae116f9b
libraries/primitive|75c3379b6d76e914cc3c7ffd290b6b1cad7ea3e6
libraries/process|76fb4b7e8861dec8054723a3c794c73511d07bb2
libraries/random|69bfde219bab869729fdbe9c1496371f912bf41e
libraries/stm|f3a4ab56195f943e149ccc14fbfe18c00d2fea70
libraries/template-haskell|e6323fef1a67cf9d8e91ca35d71a9c89d2494413
libraries/terminfo|64d1e6201b490942636f5f3883cf5e81c2338fc8
libraries/transformers|a59fb93860f84ccd44178dcbbb82cfea7e02cd07
libraries/unix|389820b2bcdc32be728e05fd98b69382f9c55721
libraries/utf8-string|d7386bea7fe286483ea559fb9b3898be080af700
libraries/vector|c4c5a740ec977a4300449bc85f4707ec641be923
libraries/xhtml|e6dc0c800f5a1c3ac8f0fcb477b2d76394c30d38
nofib|40c01620651d93166e2b8da156f113a4e7b827de
testsuite|a95c63d1c7196c222c4f1193181cb801cc273e42
utils/haddock|fef07ac22cc89888e78233807e55c7dbf6f405f5
utils/hsc2hs|b46ae9e455a4e6766a4dba688c9bc2186056218a
-----------------------------------------------------------------------------
All done!
Nightly build finished successfully at Thu May 24 07:39:51 BST 2012

------------- GHC Test summary ---------------------

OVERALL SUMMARY for test run started at Thu May 24 02:15:22 BST 2012
    3340 total tests, which gave rise to
   12525 test cases, of which
       0 caused framework failures
    2590 were skipped

    9670 expected passes
     143 had missing libraries
     108 expected failures
       2 unexpected passes
      12 unexpected failures

Unexpected passes:
   typecheck/should_compile  tc078 (hpc,profasm)

Unexpected failures:
   ../../libraries/template-haskell/tests  dataToExpQUnit [exit code non-0] (profasm)
   dph/nbody                               dph-nbody-copy-opt [exit code non-0] (normal,threaded1)
   dph/nbody                               dph-nbody-vseg-opt [exit code non-0] (normal,threaded1)
   dph/words                               dph-words-copy-opt [exit code non-0] (normal)
   ffi/should_run                          capi_value [bad stdout or stderr] (ghci)
   ffi/should_run                          ffi_parsing_001 [bad stdout or stderr] (ghci)
   perf/compiler                           T4801 [stat too good] (normal)
   perf/compiler                           T783 [stat too good] (normal)
   perf/should_run                         T3736 [bad stderr] (normal)
   rts                                     T5423 [bad exit code] (normal)

----------------------------------------------------
Nightly run ended at Thu May 24 07:39:51 BST 2012
&lt;/pre&gt;</description>
    <dc:creator>GHC Build Reports</dc:creator>
    <dc:date>2012-05-24T06:39:52</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58352">
    <title>pgj-freebsd-amd64-stable (amd64 FreeBSD STABLE), build 568, Success</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58352</link>
    <description>&lt;pre&gt;pgj-freebsd-amd64-stable (amd64 FreeBSD STABLE), build 568

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj-freebsd-amd64-stable/568.html

git clone                    | Success
create mk/build.mk           | Success
get subrepos                 | Success
repo versions                | Success
touching clean-check files   | Success
setting version date         | Success
booting                      | Success
configuring                  | Success
creating check-remove-before | Success
compiling                    | Success
creating check-remove-after  | Success
compiling testremove         | Success
simulating clean             | Success
checking clean               | Success
making bindist               | Success
publishing bindist           | Success
testing bindist              | Success
testing                      | Success
testsuite summary            | Success

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj-freebsd-amd64-stable/568.html

File not deleted:    "compiler/ghc.cabal.old"
File not deleted:    "inplace"
File not deleted:    "libraries/base/base.buildinfo"
File not deleted:    "libraries/base/config.log"
File not deleted:    "libraries/base/config.status"
File not deleted:    "libraries/base/include/EventConfig.h"
File not deleted:    "libraries/base/include/HsBaseConfig.h"
File not deleted:    "libraries/directory/config.log"
File not deleted:    "libraries/directory/config.status"
File not deleted:    "libraries/directory/include/HsDirectoryConfig.h"
File not deleted:    "libraries/doc-index-124.html"
File not deleted:    "libraries/doc-index-126.html"
File not deleted:    "libraries/doc-index-33.html"
File not deleted:    "libraries/doc-index-36.html"
File not deleted:    "libraries/doc-index-37.html"
File not deleted:    "libraries/doc-index-38.html"
File not deleted:    "libraries/doc-index-42.html"
File not deleted:    "libraries/doc-index-43.html"
File not deleted:    "libraries/doc-index-45.html"
File not deleted:    "libraries/doc-index-46.html"
File not deleted:    "libraries/doc-index-47.html"
File not deleted:    "libraries/doc-index-58.html"
File not deleted:    "libraries/doc-index-60.html"
File not deleted:    "libraries/doc-index-61.html"
File not deleted:    "libraries/doc-index-62.html"
File not deleted:    "libraries/doc-index-92.html"
File not deleted:    "libraries/doc-index-94.html"
File not deleted:    "libraries/doc-index-A.html"
File not deleted:    "libraries/doc-index-All.html"
File not deleted:    "libraries/doc-index-B.html"
File not deleted:    "libraries/doc-index-C.html"
File not deleted:    "libraries/doc-index-D.html"
File not deleted:    "libraries/doc-index-E.html"
File not deleted:    "libraries/doc-index-F.html"
File not deleted:    "libraries/doc-index-G.html"
File not deleted:    "libraries/doc-index-H.html"
File not deleted:    "libraries/doc-index-I.html"
File not deleted:    "libraries/doc-index-J.html"
File not deleted:    "libraries/doc-index-K.html"
File not deleted:    "libraries/doc-index-L.html"
File not deleted:    "libraries/doc-index-M.html"
File not deleted:    "libraries/doc-index-N.html"
File not deleted:    "libraries/doc-index-O.html"
File not deleted:    "libraries/doc-index-P.html"
File not deleted:    "libraries/doc-index-Q.html"
File not deleted:    "libraries/doc-index-R.html"
File not deleted:    "libraries/doc-index-S.html"
File not deleted:    "libraries/doc-index-T.html"
File not deleted:    "libraries/doc-index-U.html"
File not deleted:    "libraries/doc-index-V.html"
File not deleted:    "libraries/doc-index-W.html"
File not deleted:    "libraries/doc-index-X.html"
File not deleted:    "libraries/doc-index-Y.html"
File not deleted:    "libraries/doc-index-Z.html"
File not deleted:    "libraries/doc-index.html"
File not deleted:    "libraries/frames.html"
File not deleted:    "libraries/haddock-util.js"
File not deleted:    "libraries/hslogo-16.png"
File not deleted:    "libraries/index-frames.html"
File not deleted:    "libraries/index.html"
File not deleted:    "libraries/integer-gmp/config.log"
File not deleted:    "libraries/integer-gmp/config.status"
File not deleted:    "libraries/integer-gmp/integer-gmp.buildinfo"
File not deleted:    "libraries/minus.gif"
File not deleted:    "libraries/ocean.css"
File not deleted:    "libraries/old-time/config.log"
File not deleted:    "libraries/old-time/config.status"
File not deleted:    "libraries/old-time/include/HsTimeConfig.h"
File not deleted:    "libraries/plus.gif"
File not deleted:    "libraries/process/config.log"
File not deleted:    "libraries/process/config.status"
File not deleted:    "libraries/process/include/HsProcessConfig.h"
File not deleted:    "libraries/synopsis.png"
File not deleted:    "libraries/terminfo/config.log"
File not deleted:    "libraries/terminfo/config.status"
File not deleted:    "libraries/terminfo/terminfo.buildinfo"
File not deleted:    "libraries/time/config.log"
File not deleted:    "libraries/time/config.status"
File not deleted:    "libraries/unix/config.log"
File not deleted:    "libraries/unix/config.status"
File not deleted:    "libraries/unix/include/HsUnixConfig.h"
File not deleted:    "libraries/unix/unix.buildinfo"
File not deleted:    "mk/config.mk.old"
File not deleted:    "mk/project.mk.old"
File not deleted:    "rts/libs.depend"
File not deleted:    "rts/package.conf.inplace"
File not deleted:    "rts/package.conf.inplace.raw"

OVERALL SUMMARY for test run started at Thu May 24 06:18:42 UTC 2012
    3160 total tests, which gave rise to
   13545 test cases, of which
       1 caused framework failures
   10701 were skipped

    2751 expected passes
      80 expected failures
       0 unexpected passes
      12 unexpected failures

Unexpected failures:
   ../../libraries/directory/tests  getPermissions001 [bad exit code] (normal)
   ../../libraries/process/tests    process007 [bad stdout] (normal)
   driver                           dynHelloWorld [bad exit code] (dyn)
   driver/recomp011                 recomp011 [bad stdout] (normal)
   dynlibs                          T3807 [bad exit code] (normal)
   dynlibs                          T5373 [bad stdout] (normal)
   lib/IO                           T4113 [bad stdout] (normal)
   plugins                          plugins01 [bad exit code] (normal)
   plugins                          plugins02 [stderr mismatch] (normal)
   plugins                          plugins03 [stderr mismatch] (normal)
   rts                              T2615 [bad stdout] (normal)
   typecheck/should_fail            T5300 [stderr mismatch] (normal)

_______________________________________________
Cvs-ghc mailing list
Cvs-ghc&amp;lt; at &amp;gt;haskell.org
http://www.haskell.org/mailman/listinfo/cvs-ghc
&lt;/pre&gt;</description>
    <dc:creator>Builder</dc:creator>
    <dc:date>2012-05-24T06:34:45</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58351">
    <title>pgj2 (amd64 FreeBSD HEAD), build 686, Success</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58351</link>
    <description>&lt;pre&gt;pgj2 (amd64 FreeBSD HEAD), build 686

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj2/686.html

git clone                    | Success
create mk/build.mk           | Success
get subrepos                 | Success
repo versions                | Success
touching clean-check files   | Success
setting version date         | Success
booting                      | Success
configuring                  | Success
creating check-remove-before | Success
compiling                    | Success
creating check-remove-after  | Success
compiling testremove         | Success
simulating clean             | Success
checking clean               | Success
making bindist               | Success
publishing bindist           | Success
testing bindist              | Success
testing                      | Success
testsuite summary            | Success

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj2/686.html

File not deleted:    "compiler/ghc.cabal.old"
File not deleted:    "inplace"
File not deleted:    "libraries/base/include/EventConfig.h"
Deleted before file: "libraries/time/include/HsTimeConfig.h"
File not deleted:    "mk/config.mk.old"
File not deleted:    "mk/project.mk.old"
File not deleted:    "rts/libs.depend"
File not deleted:    "rts/package.conf.inplace"
File not deleted:    "rts/package.conf.inplace.raw"

OVERALL SUMMARY for test run started at Thu May 24 04:57:48 UTC 2012
    3317 total tests, which gave rise to
   14080 test cases, of which
       0 caused framework failures
   11082 were skipped

    2896 expected passes
      48 had missing libraries
      35 expected failures
       0 unexpected passes
      19 unexpected failures

Unexpected failures:
   ../../libraries/directory/tests      T4113 [bad stdout] (normal)
   ../../libraries/directory/tests      getPermissions001 [bad exit code] (normal)
   ../../libraries/process/tests        process007 [bad stdout] (normal)
   ../../libraries/unix/tests/libposix  posix005 [bad stdout] (normal)
   driver                               dynHelloWorld [bad exit code] (dyn)
   driver/recomp011                     recomp011 [bad stdout] (normal)
   dynlibs                              T3807 [bad exit code] (normal)
   dynlibs                              T5373 [bad stdout] (normal)
   ghci/scripts                         T5979 [bad stderr] (ghci)
   ghci/scripts                         T6106 [bad stderr] (ghci)
   indexed-types/should_compile         GivenCheckDecomp [stderr mismatch] (normal)
   indexed-types/should_fail            T4272 [stderr mismatch] (normal)
   perf/compiler                        parsing001 [stat too good] (normal)
   plugins                              plugins01 [bad exit code] (normal)
   plugins                              plugins02 [stderr mismatch] (normal)
   plugins                              plugins03 [stderr mismatch] (normal)
   rts                                  T2615 [bad stdout] (normal)
   typecheck/should_fail                T5300 [stderr mismatch] (normal)
   typecheck/should_fail                T5691 [stderr mismatch] (normal)

_______________________________________________
Cvs-ghc mailing list
Cvs-ghc&amp;lt; at &amp;gt;haskell.org
http://www.haskell.org/mailman/listinfo/cvs-ghc
&lt;/pre&gt;</description>
    <dc:creator>Builder</dc:creator>
    <dc:date>2012-05-24T05:30:16</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58350">
    <title>pgj-freebsd-i386-stable (x86 FreeBSD STABLE), build 551, Success</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58350</link>
    <description>&lt;pre&gt;pgj-freebsd-i386-stable (x86 FreeBSD STABLE), build 551

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj-freebsd-i386-stable/551.html

git clone                    | Success
create mk/build.mk           | Success
get subrepos                 | Success
repo versions                | Success
touching clean-check files   | Success
setting version date         | Success
booting                      | Success
configuring                  | Success
creating check-remove-before | Success
compiling                    | Success
creating check-remove-after  | Success
compiling testremove         | Success
simulating clean             | Success
checking clean               | Success
making bindist               | Success
publishing bindist           | Success
testing bindist              | Success
testing                      | Success
testsuite summary            | Success

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj-freebsd-i386-stable/551.html

File not deleted:    "compiler/ghc.cabal.old"
File not deleted:    "inplace"
File not deleted:    "libraries/base/base.buildinfo"
File not deleted:    "libraries/base/config.log"
File not deleted:    "libraries/base/config.status"
File not deleted:    "libraries/base/include/EventConfig.h"
File not deleted:    "libraries/base/include/HsBaseConfig.h"
File not deleted:    "libraries/directory/config.log"
File not deleted:    "libraries/directory/config.status"
File not deleted:    "libraries/directory/include/HsDirectoryConfig.h"
File not deleted:    "libraries/doc-index-124.html"
File not deleted:    "libraries/doc-index-126.html"
File not deleted:    "libraries/doc-index-33.html"
File not deleted:    "libraries/doc-index-36.html"
File not deleted:    "libraries/doc-index-37.html"
File not deleted:    "libraries/doc-index-38.html"
File not deleted:    "libraries/doc-index-42.html"
File not deleted:    "libraries/doc-index-43.html"
File not deleted:    "libraries/doc-index-45.html"
File not deleted:    "libraries/doc-index-46.html"
File not deleted:    "libraries/doc-index-47.html"
File not deleted:    "libraries/doc-index-58.html"
File not deleted:    "libraries/doc-index-60.html"
File not deleted:    "libraries/doc-index-61.html"
File not deleted:    "libraries/doc-index-62.html"
File not deleted:    "libraries/doc-index-92.html"
File not deleted:    "libraries/doc-index-94.html"
File not deleted:    "libraries/doc-index-A.html"
File not deleted:    "libraries/doc-index-All.html"
File not deleted:    "libraries/doc-index-B.html"
File not deleted:    "libraries/doc-index-C.html"
File not deleted:    "libraries/doc-index-D.html"
File not deleted:    "libraries/doc-index-E.html"
File not deleted:    "libraries/doc-index-F.html"
File not deleted:    "libraries/doc-index-G.html"
File not deleted:    "libraries/doc-index-H.html"
File not deleted:    "libraries/doc-index-I.html"
File not deleted:    "libraries/doc-index-J.html"
File not deleted:    "libraries/doc-index-K.html"
File not deleted:    "libraries/doc-index-L.html"
File not deleted:    "libraries/doc-index-M.html"
File not deleted:    "libraries/doc-index-N.html"
File not deleted:    "libraries/doc-index-O.html"
File not deleted:    "libraries/doc-index-P.html"
File not deleted:    "libraries/doc-index-Q.html"
File not deleted:    "libraries/doc-index-R.html"
File not deleted:    "libraries/doc-index-S.html"
File not deleted:    "libraries/doc-index-T.html"
File not deleted:    "libraries/doc-index-U.html"
File not deleted:    "libraries/doc-index-V.html"
File not deleted:    "libraries/doc-index-W.html"
File not deleted:    "libraries/doc-index-X.html"
File not deleted:    "libraries/doc-index-Y.html"
File not deleted:    "libraries/doc-index-Z.html"
File not deleted:    "libraries/doc-index.html"
File not deleted:    "libraries/frames.html"
File not deleted:    "libraries/haddock-util.js"
File not deleted:    "libraries/hslogo-16.png"
File not deleted:    "libraries/index-frames.html"
File not deleted:    "libraries/index.html"
File not deleted:    "libraries/integer-gmp/config.log"
File not deleted:    "libraries/integer-gmp/config.status"
File not deleted:    "libraries/integer-gmp/integer-gmp.buildinfo"
File not deleted:    "libraries/minus.gif"
File not deleted:    "libraries/ocean.css"
File not deleted:    "libraries/old-time/config.log"
File not deleted:    "libraries/old-time/config.status"
File not deleted:    "libraries/old-time/include/HsTimeConfig.h"
File not deleted:    "libraries/plus.gif"
File not deleted:    "libraries/process/config.log"
File not deleted:    "libraries/process/config.status"
File not deleted:    "libraries/process/include/HsProcessConfig.h"
File not deleted:    "libraries/synopsis.png"
File not deleted:    "libraries/terminfo/config.log"
File not deleted:    "libraries/terminfo/config.status"
File not deleted:    "libraries/terminfo/terminfo.buildinfo"
File not deleted:    "libraries/time/config.log"
File not deleted:    "libraries/time/config.status"
File not deleted:    "libraries/unix/config.log"
File not deleted:    "libraries/unix/config.status"
File not deleted:    "libraries/unix/include/HsUnixConfig.h"
File not deleted:    "libraries/unix/unix.buildinfo"
File not deleted:    "mk/config.mk.old"
File not deleted:    "mk/project.mk.old"
File not deleted:    "rts/libs.depend"
File not deleted:    "rts/package.conf.inplace"
File not deleted:    "rts/package.conf.inplace.raw"

OVERALL SUMMARY for test run started at Thu May 24 04:54:17 UTC 2012
    3160 total tests, which gave rise to
   13545 test cases, of which
       1 caused framework failures
   10702 were skipped

    2741 expected passes
      79 expected failures
       5 unexpected passes
      17 unexpected failures

Unexpected passes:
   ../../libraries/unix/tests  getEnvironment01 (normal)
   ../../libraries/unix/tests  getEnvironment02 (normal)
   ../../libraries/unix/tests  getGroupEntryForName (normal)
   ../../libraries/unix/tests  getUserEntryForName (normal)
   ../../libraries/unix/tests  queryfdoption01 (normal)

Unexpected failures:
   ../../libraries/directory/tests  getPermissions001 [bad exit code] (normal)
   ../../libraries/process/tests    process007 [bad stdout] (normal)
   driver                           dynHelloWorld [bad exit code] (dyn)
   driver/recomp011                 recomp011 [bad stdout] (normal)
   dynlibs                          T3807 [bad exit code] (normal)
   dynlibs                          T5373 [bad stdout] (normal)
   indexed-types/should_compile     T3851 [stderr mismatch] (normal)
   layout                           layout001 [bad stderr] (normal)
   lib/IO                           T4113 [bad stdout] (normal)
   numeric/should_run               numrun012 [bad stdout] (normal)
   plugins                          plugins01 [bad exit code] (normal)
   plugins                          plugins02 [stderr mismatch] (normal)
   plugins                          plugins03 [stderr mismatch] (normal)
   rts                              T2615 [bad stdout] (normal)
   typecheck/bug1465                bug1465 [bad stderr] (normal)
   typecheck/should_fail            T5300 [stderr mismatch] (normal)
   typecheck/should_fail            tcfail101 [stderr mismatch] (normal)

_______________________________________________
Cvs-ghc mailing list
Cvs-ghc&amp;lt; at &amp;gt;haskell.org
http://www.haskell.org/mailman/listinfo/cvs-ghc
&lt;/pre&gt;</description>
    <dc:creator>Builder</dc:creator>
    <dc:date>2012-05-24T05:28:52</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58349">
    <title>[nightly] 23-May-2012 build of STABLE on i386-unknown-linux(cam-02-unx)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58349</link>
    <description>&lt;pre&gt;Build description = STABLE on i386-unknown-linux (cam-02-unx)
Build location    = /playpen/simonmar/nightly/STABLE
Build config file = /home/simonmar/nightly/site/msrc/conf-STABLE-cam-02-unx

Nightly build started on cam-02-unx at Wed May 23 18:10:01 BST 2012.
**** checking out new source tree                 ... warning: Remote branch ghc-7.4 not found in upstream origin, using HEAD instead
warning: Remote branch ghc-7.4 not found in upstream origin, using HEAD instead
ok.
**** Building stage 1 compiler                    ... ok.
GHC Version 7.4.1.20120516
**** Building stage 2 compiler                    ... ok.
**** Building stage 3 compiler                    ... ok.
**** building testsuite tools                     ... ok.
**** running tests                                ... ok (summary below).
**** building compiler binary distribution        ... ok.
**** uploading binary distribution                ... failed.
**** running nofib (-rtsopts -O2)                 ... ok.
**** running nofib (-rtsopts -O2 -fllvm)          ... ok. (6 failures)
**** running nofib (-rtsopts -O2 -prof -auto-all) ... ok. (2 failures)
**** running nofib (-rtsopts -O2 -prof -auto-all -fllvm)... ok. (1 failures)
**** publishing logs                              ... ssh: connect to host haskell.org port 22: Connection timed out
lost connection
failed.
Logs  are at http://www.haskell.org/ghc/dist/stable/logs
Dists are at http://www.haskell.org/ghc/dist/stable/dist
Docs  are at http://www.haskell.org/ghc/dist/stable/docs
-----------------------------------------------------------------------------
Respository hashes:
.|06ac4cf62828afe244c6bec946f22d2ad874c4ea
ghc-tarballs|01a8e25294fd5d501e0db115debafd4fd61970a0
libraries/Cabal|5ec3c8add63e13f508a26ebea109c60570966020
libraries/Win32|1eeb98baf338f81dc6001c7a2e9b05c95b7971a8
libraries/array|c671173d695617bc66c8ff52f5adc5847bebd358
libraries/base|41b87900b41fc6a88e75cd533344e554ad22efb6
libraries/binary|080f85c7b0ccc59a579b85d50132d62cb469b146
libraries/bytestring|b3cdac4bbdcfbe4ca384076c20ebd0def534f528
libraries/containers|fff28d7c1cd8e6e39aa5e099c6e5611ff1b95a19
libraries/deepseq|eded7da15fc03cfdd3be4bc2661c658eaa7c6d68
libraries/directory|03bcfde61e6c95043ff312e9544e6ad0d9dd96c9
libraries/extensible-exceptions|92d6c24745c2baa5f1a7aa34cbfd59457638f346
libraries/filepath|efa44de9abfab7fe3053c3d2ca6be965703dd04d
libraries/ghc-prim|60a85ba01303e1a28024e9983f5e9733fbd4888c
libraries/haskeline|647894c3bf28da59515a59abfd5dd2efff48936e
libraries/haskell2010|d1e29ce3a56d6a34bd82e9e7ccd396b6bec963ed
libraries/haskell98|4c71385d929b11dca8d2f41a96ca8a4b5aad9c3e
libraries/hoopl|4b2fa9c4b6af00ef6759ff62a2b3efa7d9a8e59c
libraries/hpc|ffd12b9a17dfdffef8ca4dd215e5c081d9b082fa
libraries/integer-gmp|d95eb887c0e8ed012065e2fd60c234a8db0eebf7
libraries/integer-simple|bc04c4f51a3edcd7145a66ffac796adb2eed4a11
libraries/mtl|a41470c1890073e678f0dca2a9ef4c02d55bf7c6
libraries/old-locale|b512c2988a36df94486ab55d7c7c10be9439b09c
libraries/old-time|bf84632130de935f63a52bfcf934dda7014fd960
libraries/pretty|f615a6aeb4abcdbfbfab67b0a82cef9a9a65ec49
libraries/process|d26eba94031fb129c40e6441f9960f315b1010f9
libraries/template-haskell|73e2749647f8ac21dbb0eea3d6df7c6834494a04
libraries/terminfo|baec6aff59d13ba294b370f9563e8068706392ce
libraries/unix|4152c1b17d8633dac8f830f334688393e527b061
libraries/utf8-string|ec2b85940a256dbc8771e5e2065ca8f76cc802d0
libraries/xhtml|aca0f6eeaea0fbacb492e9a5c1bb4ec35a1b70f7
nofib|40c01620651d93166e2b8da156f113a4e7b827de
testsuite|f13979449a837fa25526d3b23702a6e8aabed963
utils/haddock|d92d5a98adab5a94d34b763b9f4fd07557977ccb
utils/hsc2hs|385fc7dbeaf957976017a6159128bb697bbafa75
-----------------------------------------------------------------------------
All done!
Nightly build finished successfully at Thu May 24 06:01:22 BST 2012

------------- GHC Test summary ---------------------

OVERALL SUMMARY for test run started at Wed May 23 23:22:21 BST 2012
    3160 total tests, which gave rise to
   15591 test cases, of which
       0 caused framework failures
    3311 were skipped

   11837 expected passes
     440 expected failures
       0 unexpected passes
       3 unexpected failures

Unexpected failures:
   profiling/should_run         T949 [bad heap profile] (prof_hd)
   programs/barton-mangler-bug  barton-mangler-bug [bad heap profile] (profasm)
   rts                          5250 [bad exit code] (optllvm)

----------------------------------------------------
Nightly run ended at Thu May 24 06:01:22 BST 2012
&lt;/pre&gt;</description>
    <dc:creator>GHC Build Reports</dc:creator>
    <dc:date>2012-05-24T05:01:24</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58348">
    <title>pgj (x86 FreeBSD HEAD), build 688, Success</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58348</link>
    <description>&lt;pre&gt;pgj (x86 FreeBSD HEAD), build 688

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj/688.html

git clone                    | Success
create mk/build.mk           | Success
get subrepos                 | Success
repo versions                | Success
touching clean-check files   | Success
setting version date         | Success
booting                      | Success
configuring                  | Success
creating check-remove-before | Success
compiling                    | Success
creating check-remove-after  | Success
compiling testremove         | Success
simulating clean             | Success
checking clean               | Success
making bindist               | Success
publishing bindist           | Success
testing bindist              | Success
testing                      | Success
testsuite summary            | Success

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/pgj/688.html

File not deleted:    "compiler/ghc.cabal.old"
File not deleted:    "inplace"
File not deleted:    "libraries/base/include/EventConfig.h"
Deleted before file: "libraries/time/include/HsTimeConfig.h"
File not deleted:    "mk/config.mk.old"
File not deleted:    "mk/project.mk.old"
File not deleted:    "rts/libs.depend"
File not deleted:    "rts/package.conf.inplace"
File not deleted:    "rts/package.conf.inplace.raw"

OVERALL SUMMARY for test run started at Thu May 24 02:42:56 UTC 2012
    3317 total tests, which gave rise to
   14080 test cases, of which
       0 caused framework failures
   11083 were skipped

    2886 expected passes
      48 had missing libraries
      34 expected failures
       5 unexpected passes
      24 unexpected failures

Unexpected passes:
   ../../libraries/unix/tests  getEnvironment01 (normal)
   ../../libraries/unix/tests  getEnvironment02 (normal)
   ../../libraries/unix/tests  getGroupEntryForName (normal)
   ../../libraries/unix/tests  getUserEntryForName (normal)
   ../../libraries/unix/tests  queryfdoption01 (normal)

Unexpected failures:
   ../../libraries/directory/tests      T4113 [bad stdout] (normal)
   ../../libraries/directory/tests      getPermissions001 [bad exit code] (normal)
   ../../libraries/process/tests        process007 [bad stdout] (normal)
   ../../libraries/unix/tests/libposix  posix005 [bad stdout] (normal)
   driver                               dynHelloWorld [bad exit code] (dyn)
   driver/1372                          1372 [bad stderr] (normal)
   driver/recomp011                     recomp011 [bad stdout] (normal)
   dynlibs                              T3807 [bad exit code] (normal)
   dynlibs                              T5373 [bad stdout] (normal)
   ffi/should_fail                      ccfail001 [stderr mismatch] (normal)
   ghci/scripts                         T5979 [bad stderr] (ghci)
   ghci/scripts                         T6106 [bad stderr] (ghci)
   numeric/should_run                   numrun012 [bad stdout] (normal)
   parser/should_fail                   readFail033 [stderr mismatch] (normal)
   perf/compiler                        T3064 [stat not good enough] (normal)
   plugins                              plugins01 [bad exit code] (normal)
   plugins                              plugins02 [stderr mismatch] (normal)
   plugins                              plugins03 [stderr mismatch] (normal)
   rts                                  T2615 [bad stdout] (normal)
   safeHaskell/flags                    SafeFlags23 [stderr mismatch] (normal)
   th                                   T5665 [stderr mismatch] (normal)
   typecheck/should_compile             tc026 [stderr mismatch] (normal)
   typecheck/should_fail                T5300 [stderr mismatch] (normal)
   typecheck/should_fail                T5691 [stderr mismatch] (normal)

_______________________________________________
Cvs-ghc mailing list
Cvs-ghc&amp;lt; at &amp;gt;haskell.org
http://www.haskell.org/mailman/listinfo/cvs-ghc
&lt;/pre&gt;</description>
    <dc:creator>Builder</dc:creator>
    <dc:date>2012-05-24T03:16:07</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58347">
    <title>[nightly] 23-May-2012 build of HEAD on x86_64-unknown-linux(cam-04-unx)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58347</link>
    <description>&lt;pre&gt;Build description = HEAD on x86_64-unknown-linux (cam-04-unx)
Build location    = /64playpen/simonmar/nightly/HEAD-cam-04-unx
Build config file = /home/simonmar/nightly/site/msrc/conf-HEAD-cam-04-unx

Nightly build started on cam-04-unx at Wed May 23 18:00:01 BST 2012.
**** checking out new source tree                 ... ok.
**** Building stage 1 compiler                    ... ok.
GHC Version 7.5.20120523
**** Building stage 2 compiler                    ... ok.
**** Building stage 3 compiler                    ... ok.
**** building source distribution                 ... ok.
**** uploading source distribution                ... ok.
**** building testsuite tools                     ... ok.
**** running tests                                ... ok (summary below).
**** building compiler binary distribution        ... ok.
**** uploading binary distribution                ... ok.
**** running nofib (-rtsopts -O2)                 ... ok.
**** running nofib (-rtsopts -O2 -fllvm)          ... ok.
**** running nofib (-rtsopts -O2 -prof -auto-all) ... ok.
**** running nofib (-rtsopts -O2 -prof -auto-all -fllvm)... ok.
**** publishing logs                              ... ok.
Logs  are at http://www.haskell.org/ghc/dist/current/logs
Dists are at http://www.haskell.org/ghc/dist/current/dist
Docs  are at http://www.haskell.org/ghc/dist/current/docs
-----------------------------------------------------------------------------
Respository hashes:
.|634fb8d3b569276504be317783ade54508633b10
ghc-tarballs|5e1f5d19ef2f836d180947aadc0dd9a9851edf28
libraries/Cabal|cc2c5a78f8fd5b2ab2c0dd3629a8184e7e0c95c4
libraries/Win32|bda29f7fe0b61b70f558549407e598c9256ad293
libraries/array|2a3d41bcae1d0a5d192e614370459dfdd31f3bcf
libraries/base|dc521b8b23847b07072a1aea0f56614ae2370e02
libraries/binary|527be910f16a4bc047069281fc58bc6748e5fecc
libraries/bytestring|fc8e1ee849b10fe2b63eb1024aff3d6624ddd069
libraries/containers|d4e8b5bd70f87af4463410df3aade72d42d675e0
libraries/deepseq|61d95ab64b1610817288e6f6b880ca2770fcc68f
libraries/directory|854bd9e4ec8c502327300c939ad197cbc39bde2c
libraries/dph|01416ec30eb73ac512cdf894a7bb44e5cebd8457
libraries/filepath|f451c8b4330fb69573533ed19a2645afa936ccaf
libraries/ghc-prim|529167773a9a036d7d3262707be4c5a2f6a04bcf
libraries/haskeline|bd39c0ce02ad07515450bfe5d667ce1635221b04
libraries/haskell2010|07f24cea759fae7994c89d77fae199862d9e2acf
libraries/haskell98|857ba8b14bba4b597d104e3d7264aee4bb4e74ae
libraries/hoopl|1ef68d6f2a8a7e89a5ed4cc78e3fefc89dc8ccab
libraries/hpc|4d661848575009bbcf3fe8e1f7c69da12f1d3a8e
libraries/integer-gmp|121cd52f9ae00ff0d6d072cc51939fb887db3fba
libraries/integer-simple|87ce6a97d7a07badc73d599a7b2ee629b2967866
libraries/old-locale|201f149646b5c2be6145436449d66bc69563c635
libraries/old-time|b2c2c9d01c3c71a9a37c11b455aba63b7a3199c2
libraries/parallel|e8ee35f4bb43cfde410d27e056d4083ced0a24c9
libraries/pretty|ab7e8d91470bb94c9e184dffbec89d0aae116f9b
libraries/primitive|75c3379b6d76e914cc3c7ffd290b6b1cad7ea3e6
libraries/process|76fb4b7e8861dec8054723a3c794c73511d07bb2
libraries/random|69bfde219bab869729fdbe9c1496371f912bf41e
libraries/stm|f3a4ab56195f943e149ccc14fbfe18c00d2fea70
libraries/template-haskell|e6323fef1a67cf9d8e91ca35d71a9c89d2494413
libraries/terminfo|64d1e6201b490942636f5f3883cf5e81c2338fc8
libraries/transformers|a59fb93860f84ccd44178dcbbb82cfea7e02cd07
libraries/unix|389820b2bcdc32be728e05fd98b69382f9c55721
libraries/utf8-string|d7386bea7fe286483ea559fb9b3898be080af700
libraries/vector|c4c5a740ec977a4300449bc85f4707ec641be923
libraries/xhtml|e6dc0c800f5a1c3ac8f0fcb477b2d76394c30d38
nofib|40c01620651d93166e2b8da156f113a4e7b827de
testsuite|a95c63d1c7196c222c4f1193181cb801cc273e42
utils/haddock|fef07ac22cc89888e78233807e55c7dbf6f405f5
utils/hsc2hs|b46ae9e455a4e6766a4dba688c9bc2186056218a
-----------------------------------------------------------------------------
All done!
Nightly build finished successfully at Thu May 24 02:41:04 BST 2012

------------- GHC Test summary ---------------------

OVERALL SUMMARY for test run started at Wed May 23 22:08:44 BST 2012
    3340 total tests, which gave rise to
   16429 test cases, of which
       0 caused framework failures
    3543 were skipped

   12553 expected passes
     194 had missing libraries
     131 expected failures
       4 unexpected passes
       4 unexpected failures

Unexpected passes:
   typecheck/should_compile  tc078 (hpc,optasm,profasm)
   typecheck/should_compile  tc126 (optasm)

Unexpected failures:
   ../../libraries/template-haskell/tests  dataToExpQUnit [exit code non-0] (profasm)
   ffi/should_run                          capi_value [bad stdout or stderr] (ghci)
   ffi/should_run                          ffi_parsing_001 [bad stdout or stderr] (ghci)
   perf/compiler                           T4801 [stat not good enough] (normal)

----------------------------------------------------
Nightly run ended at Thu May 24 02:41:04 BST 2012
&lt;/pre&gt;</description>
    <dc:creator>GHC Build Reports</dc:creator>
    <dc:date>2012-05-24T01:41:05</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58346">
    <title>am-deb7-64 (HEAD), build 104, Success</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58346</link>
    <description>&lt;pre&gt;am-deb7-64 (HEAD), build 104

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/am-deb7-64/104.html

git clone                    | Success
create mk/build.mk           | Success
get subrepos                 | Success
repo versions                | Success
touching clean-check files   | Success
setting version date         | Success
booting                      | Success
configuring                  | Success
creating check-remove-before | Success
compiling                    | Success
creating check-remove-after  | Success
compiling testremove         | Success
simulating clean             | Success
checking clean               | Success
making bindist               | Success
testing bindist              | Success
testing                      | Success
testsuite summary            | Success

Build succeeded
Details: http://darcs.haskell.org/ghcBuilder/builders/am-deb7-64/104.html

File not deleted:    "compiler/ghc.cabal.old"
File not deleted:    "inplace"
File not deleted:    "libraries/base/include/EventConfig.h"
Deleted before file: "libraries/time/include/HsTimeConfig.h"
File not deleted:    "mk/config.mk.old"
File not deleted:    "mk/project.mk.old"
File not deleted:    "rts/libs.depend"
File not deleted:    "rts/package.conf.inplace"
File not deleted:    "rts/package.conf.inplace.raw"

OVERALL SUMMARY for test run started at Thu May 24 03:16:44 MSK 2012
    3317 total tests, which gave rise to
   14080 test cases, of which
       0 caused framework failures
   11082 were skipped

    2909 expected passes
      48 had missing libraries
      35 expected failures
       0 unexpected passes
       6 unexpected failures

Unexpected failures:
   ghci/scripts           T5979 [bad stderr] (ghci)
   perf/compiler          T4801 [stat not good enough] (normal)
   perf/compiler          parsing001 [stat too good] (normal)
   rts                    testblockalloc [bad exit code] (normal)
   typecheck/should_fail  T5300 [stderr mismatch] (normal)
   typecheck/should_fail  T5691 [stderr mismatch] (normal)

_______________________________________________
Cvs-ghc mailing list
Cvs-ghc&amp;lt; at &amp;gt;haskell.org
http://www.haskell.org/mailman/listinfo/cvs-ghc
&lt;/pre&gt;</description>
    <dc:creator>Builder</dc:creator>
    <dc:date>2012-05-24T00:25:32</dc:date>
  </item>
  <textinput rdf:about="http://search.gmane.org/?group=$group=gmane.comp.lang.haskell.cvs.ghc">
    <title>Search Engine</title>
    <description>Search the mailing list at Gmane</description>
    <name>query</name>
    <link>http://search.gmane.org/?group=$group=gmane.comp.lang.haskell.cvs.ghc</link>
  </textinput>
</rdf:RDF>


diff --git a/compiler/deSugar/DsMeta.hs b/compiler/deSugar/DsMeta.hs
index 6d1520b..625c17a 100644
--- a/compiler/deSugar/DsMeta.hs
+++ b/compiler/deSugar/DsMeta.hs
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -280,7 +280,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; mk_extra_tvs :: Located Name -&amp;gt; LHsTyVarBndrs Name
 mk_extra_tvs tc tvs defn
   | TyData { td_kindSig = Just hs_kind } &amp;lt;- defn
   = do { extra_tvs &amp;lt;- go hs_kind
-       ; return (mkHsQTvs (hsQTvBndrs tvs ++ extra_tvs)) }
+       ; return (tvs { hsq_tvs = hsq_tvs tvs ++ extra_tvs }) }
   | otherwise
   = return tvs
   where
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -360,7 +360,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; repFamInstD (FamInstDecl { fid_tycon = tc_name
                                                 -- polymorphism in Template Haskell (sigh)
     do { tc &amp;lt;- lookupLOcc tc_name -- See note [Binders and occurrences]  
        ; let loc = getLoc tc_name
-             hs_tvs = mkHsQTvs (userHsTyVarBndrs loc tv_names)   -- Yuk
+             hs_tvs = HsQTvs { hsq_kvs = kv_names, hsq_tvs = userHsTyVarBndrs loc tv_names }   -- Yuk
        ; addTyClTyVarBinds hs_tvs $ \ bndrs -&amp;gt;
          do { tys1 &amp;lt;- repLTys tys
             ; tys2 &amp;lt;- coreList typeQTyConName tys1
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -420,27 +420,30 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; ds_msg = ptext (sLit "Cannot desugar this Template Haskell declaration:")
 
 repC :: [Name] -&amp;gt; LConDecl Name -&amp;gt; DsM (Core TH.ConQ)
 repC _ (L _ (ConDecl { con_name = con, con_qvars = con_tvs, con_cxt = L _ []
-                       , con_details = details, con_res = ResTyH98 }))
+                     , con_details = details, con_res = ResTyH98 }))
   | null (hsQTvBndrs con_tvs)
-  = do { con1 &amp;lt;- lookupLOcc con -- See note [Binders and occurrences] 
+  = do { con1 &amp;lt;- lookupLOcc con -- See Note [Binders and occurrences] 
        ; repConstr con1 details  }
+
 repC tvs (L _ (ConDecl { con_name = con
                        , con_qvars = con_tvs, con_cxt = L _ ctxt
                        , con_details = details
                        , con_res = res_ty }))
   = do { (eq_ctxt, con_tv_subst) &amp;lt;- mkGadtCtxt tvs res_ty
-       ; let ex_tvs = mkHsQTvs [ tv | tv &amp;lt;- hsQTvBndrs con_tvs, not (hsLTyVarName tv `in_subst` con_tv_subst)]
+       ; let ex_tvs = HsQTvs { hsq_kvs = filterOut (in_subst con_tv_subst) (hsq_kvs con_tvs)
+                             , hsq_tvs = filterOut (in_subst con_tv_subst . hsLTyVarName) (hsq_tvs con_tvs) }
+
        ; binds &amp;lt;- mapM dupBinder con_tv_subst 
        ; dsExtendMetaEnv (mkNameEnv binds) $     -- Binds some of the con_tvs
          addTyVarBinds ex_tvs $ \ ex_bndrs -&amp;gt;   -- Binds the remaining con_tvs
-    do { con1      &amp;lt;- lookupLOcc con -- See note [Binders and occurrences] 
+    do { con1      &amp;lt;- lookupLOcc con -- See Note [Binders and occurrences] 
        ; c'        &amp;lt;- repConstr con1 details
        ; ctxt'     &amp;lt;- repContext (eq_ctxt ++ ctxt)
        ; rep2 forallCName [unC ex_bndrs, unC ctxt', unC c'] } }
 
-in_subst :: Name -&amp;gt; [(Name,Name)] -&amp;gt; Bool
-in_subst _ []          = False
-in_subst n ((n',_):ns) = n==n' || in_subst n ns
+in_subst :: [(Name,Name)] -&amp;gt; Name -&amp;gt; Bool
+in_subst []          _ = False
+in_subst ((n',_):ns) n = n==n' || in_subst ns n
 
 mkGadtCtxt :: [Name]-- Tyvars of the data type
            -&amp;gt; ResType (LHsType Name)
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -472,7 +475,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; mkGadtCtxt data_tvs (ResTyGADT res_ty)
     go cxt subst ((data_tv, ty) : rest)
        | Just con_tv &amp;lt;- is_hs_tyvar ty
        , isTyVarName con_tv
-       , not (in_subst con_tv subst)
+       , not (in_subst subst con_tv)
        = go cxt ((con_tv, data_tv) : subst) rest
        | otherwise
        = go (eq_pred : cxt) subst rest
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -628,7 +631,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; addTyVarBinds :: LHsTyVarBndrs Name                       -- the binders to be
 -- meta environment and gets the *new* names on Core-level as an argument
 
 addTyVarBinds tvs m
-  = do { freshNames &amp;lt;- mkGenSyms (hsLTyVarNames tvs)
+  = do { freshNames &amp;lt;- mkGenSyms (hsLKiTyVarNames tvs)
        ; term &amp;lt;- addBinds freshNames $ 
      do { kbs1 &amp;lt;- mapM mk_tv_bndr (hsQTvBndrs tvs `zip` freshNames)
                     ; kbs2 &amp;lt;- coreList tyVarBndrTyConName kbs1
&amp;lt; at &amp;gt;&amp;lt; at &amp;gt; -647,7 +650,7 &amp;lt; at &amp;gt;&amp;lt; at &amp;gt; addTyClTyVarBinds :: LHsTyVarBndrs Name
 --      type W (T a) = blah
 -- The 'a' in the type instance is the one bound by the instance decl
 addTyClTyVarBinds tvs m
-  = do { let tv_names = hsLTyVarNames tvs
+  = do { let tv_names = hsLKiTyVarNames tvs
        ; env &amp;lt;- dsGetMetaEnv
        ; freshNames &amp;lt;- mkGenSyms (filterOut (`elemNameEnv` env) tv_names)
            -- Make fresh names for the ones that are not already in scope
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:05</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58358">
    <title>[commit: ghc] master: Merge branch 'master' ofhttp://darcs.haskell.org/ghc (44febbc)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58358</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/44febbcca3255cca222a1489e582d283d7bd9b04


commit 44febbcca3255cca222a1489e582d283d7bd9b04
Merge: 1050b33... 22b51da...
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Tue May 22 15:15:26 2012 +0100

    Merge branch 'master' of http://darcs.haskell.org/ghc

 aclocal.m4                     |   71 +++++++++++---------------
 compiler/deSugar/DsForeign.lhs |   25 +++++++--
 compiler/main/DynFlags.hs      |    4 ++
 compiler/main/GhcMake.hs       |   27 +++++-----
 compiler/prelude/PrelNames.lhs |    6 +-
 compiler/utils/Panic.lhs       |   36 ++++++++-----
 configure.ac                   |    2 +-
 ghc.mk                         |    3 +-
 ghc/GhciMonad.hs               |    3 +-
 ghc/InteractiveUI.hs           |    3 +-
 ghc/ghc-bin.cabal.in           |    2 +-
 packages                       |    1 -
 rts/Adjustor.c                 |  112 ++++++++++++++++++++++++++--------------
 rts/Prelude.h                  |    8 ++--
 rts/package.conf.in            |    4 +-
 rts/win32/libHSbase.def        |    1 -
 utils/runghc/runghc.hs         |   14 +++--
 validate                       |    7 ++-
 18 files changed, 189 insertions(+), 140 deletions(-)
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:04:59</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58357">
    <title>[commit: ghc] master: Merge branch 'master' ofhttp://darcs.haskell.org/ghc (13e4927)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58357</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/13e4927e27d352eac56c86698ab54f7e07fd0002


commit 13e4927e27d352eac56c86698ab54f7e07fd0002
Merge: 44febbc... 634fb8d...
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Thu May 24 12:21:37 2012 +0100

    Merge branch 'master' of http://darcs.haskell.org/ghc

 utils/hp2ps/Key.c |    1 +
 1 files changed, 1 insertions(+), 0 deletions(-)
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:05:02</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58356">
    <title>[commit: ghc] master: Fix scoping of kind variables in instancedeclarations (6a8b429)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58356</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/6a8b4290f002cbe042199116ae2d71955dc544a1


commit 6a8b4290f002cbe042199116ae2d71955dc544a1
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Tue May 22 15:14:48 2012 +0100

    Fix scoping of kind variables in instance declarations
    
    Fixes Trac #6118

 compiler/hsSyn/HsTypes.lhs   |   29 +++++++++++++++++---------
 compiler/rename/RnBinds.lhs  |    2 +-
 compiler/rename/RnSource.lhs |   46 +++++++++++++++++++++++++++--------------
 3 files changed, 50 insertions(+), 27 deletions(-)


Diff suppressed because of size. To see it, use:

    git show 6a8b4290f002cbe042199116ae2d71955dc544a1
&lt;/pre&gt;</description>
    <dc:creator>Simon Peyton Jones</dc:creator>
    <dc:date>2012-05-24T13:04:53</dc:date>
  </item>
  <item rdf:about="http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58355">
    <title>[commit: ghc] master: Comments only (1050b33)</title>
    <link>http://permalink.gmane.org/gmane.comp.lang.haskell.cvs.ghc/58355</link>
    <description>&lt;pre&gt;Repository : ssh://darcs.haskell.org//srv/darcs/ghc

On branch  : master

http://hackage.haskell.org/trac/ghc/changeset/1050b33632e14b119da56bfae401088dc3fd6abf


commit 1050b33632e14b119da56bfae401088dc3fd6abf
Author: Simon Peyton Jones &amp;lt;simonpj&amp;lt; at &amp;gt;microsoft.com&amp;gt;
Date:   Tue May 22 15:14:58 2012 +0100

    Comments only


 compiler/typecheck/TcMType.lhs |    2 +-
 compiler/typecheck/TcType.lhs  |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)
